FlutterBaseCustomRenderedAd class

Constructors

FlutterBaseCustomRenderedAd({required String channelName})

Properties

hashCode int
The hash code for this object.
no setterinherited
onFailAdCallback ↔ void Function(String errorMsg, int errorCode)?
getter/setter pair
onLoadAdCallback ↔ void Function(BidmadInfo? info, BidmadCustomRenderedAdData adData)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdInfo(String zoneId) Future<void>
setCallbackListener({void onLoadAd(BidmadInfo? info, BidmadCustomRenderedAdData adData)?, void onFailAd(String errorMsg, int errorCode)?}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited