FlutterBaseSplash class

Properties

adInfo BidmadInfo?
getter/setter pair
channelNm String
final
hashCode int
The hash code for this object.
no setterinherited
isReadyUIUpdateNotify bool
getter/setter pair
key String
final
onFailAdCallback ↔ void Function(String errorMsg, int errorCode)?
getter/setter pair
onLoadAdCallback ↔ void Function(BidmadInfo? info)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zoneId String
final

Methods

load() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
removeSplash() → void
resetWidgetCallback() → void
setCallbackListener({void onLoadAd(BidmadInfo? info)?, void onFailAd(String errorMsg, int errorCode)?}) → void
setResizeCallback(dynamic onResizeCallback()) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String channelNm, required String zoneId}) Future<FlutterBaseSplash>